@@ -178,15 +178,19 @@ def _init():
         if os.getenv('APP_NAME') and os.getenv('APP_NAME').strip():
             _APP_NAME = os.getenv('APP_NAME').strip().replace(' ', '_').lower()
         else:
+            os.environ['APP_NAME'] = _APP_NAME
             logger.debug(f"Not found 'APP_NAME' environment variable, changed app name to '{_APP_NAME}'.")
 
         ## Checking and creating 'logs_dir':
-        _LOGS_DIR = os.path.join(_current_dir, 'logs')
-        if ('logs_dir' in _configs_dict) and _configs_dict['logs_dir'].strip():
-            _LOGS_DIR = _configs_dict['logs_dir'].strip()
-
         if os.getenv('LOGS_DIR') and os.getenv('LOGS_DIR').strip():
             _LOGS_DIR = os.getenv('LOGS_DIR').strip()
+        else:
+            if ('logs_dir' in _configs_dict) and _configs_dict['logs_dir'].strip():
+                _LOGS_DIR = _configs_dict['logs_dir'].strip()
+            else:
+                _LOGS_DIR = os.path.join(_current_dir, 'logs')
+                logger.debug(f"Not found 'LOGS_DIR' environment variable, changed to '{_LOGS_DIR}' local directory.")
+            os.environ['LOGS_DIR'] = _LOGS_DIR
 
         if not os.path.isdir(_LOGS_DIR):
             logger.warning(f"'{_LOGS_DIR}' directory doesn't exist!")
